/** 
 **  Minimal install script for O2CPlayer - install the plugin to the invoking browser
 **/

// plugin version
var VERSION = "2.0.0.82";

// Define some global variables
var PLUGIN_PFX     = "Plugins/";
var COMPONENT_PFX  = "components/";
var PLUGIN_FILE    = "npO2CPlayer.dll";     // the main plugin file
var COMPONENT_FILE = "nsO2CPlayer.xpt";     // the type library
var mfc1 = "mfc80.dll", mfc2 = "msvcp80.dll", mfc3 = "msvcr80.dll";
var manifest1 = "Microsoft.VC80.CRT.manifest", manifest2 = "Microsoft.VC80.MFC.manifest";

// sizes in KB - reserve a little extra so it is not required to update too often
var PLUGIN_SIZE    = 2000; // DLL file
var COMPONENT_SIZE = 12;   // XPT file
var SYSTEM_SIZE = 3000;    // MS DLLs

var SOFTWARE_NAME="O2CPlayer Plugin";
// plugin ID
var PLID = "@o2c.de/o2cplayer,version=" + VERSION;
var PKG = "Plugins/ELECO/O2CPlayer";

// common prefix for MS items
var MSSHARED = "/Microsoft/shared/Plugins/";

// error return codes need some memory
var err;

// start our installation (set registry name and version)
err = initInstall(SOFTWARE_NAME, PKG, VERSION);
if (err != 0)
    cancelInstall(err);

// find target folders
var pluginsFolder = getFolder("Plugins");
var componentsFolder = getFolder("Components");
// var systemFolder = getFolder("Win System");

// Verify Disk Space
if (verifyDiskSpace(pluginsFolder, PLUGIN_SIZE) && verifyDiskSpace(componentsFolder, COMPONENT_SIZE)) {
	
	// start installing plugin shared library
	resetError();
	
	logComment("trying to add from " + PLUGIN_PFX + PLUGIN_FILE + " to " + pluginsFolder);
	
	// install the plugin shared library to the current browser's Plugin directory
	err = addFile(null, VERSION, PLUGIN_PFX + PLUGIN_FILE, pluginsFolder, null);
	if (err!=0)
	{
		logComment("Could NOT add " + PLUGIN_FILE + " to " + pluginsFolder + ":" + err);
		cancelInstall(err);
	} 
	
	// start installing xpt file
	err = addFile(null, VERSION, COMPONENT_PFX + COMPONENT_FILE, componentsFolder, null);
	if (err!=0)
	{
		logComment("Could NOT add " + COMPONENT_FILE + " to " + componentsFolder + ":" + err);
		cancelInstall(err);
	} 

}
else
{
	logComment("Cancelling current browser install due to lack of space...");
	cancellInstall();
}

// check if we need to install MFC DLLs
if (!File.exists(getFolder("Plugins", mfc1)) || !File.exists(getFolder("Plugins", mfc2)) || !File.exists(getFolder("Plugins", mfc3))
    || !File.exists(getFolder("Plugins", manifest1)) || !File.exists(getFolder("Plugins", manifest2))) {
    err = addFile(MSSHARED + mfc1, null, PLUGIN_PFX + mfc1, pluginsFolder, null);
    if (err != 0)
        cancelInstall(err);
    err = addFile(MSSHARED + mfc2, null, PLUGIN_PFX + mfc2, pluginsFolder, null);
    if (err != 0)
        cancelInstall(err);
    err = addFile(MSSHARED + mfc3, null, PLUGIN_PFX + mfc3, pluginsFolder, null);
    if (err != 0)
        cancelInstall(err);
    err = addFile(MSSHARED + manifest1, null, PLUGIN_PFX + manifest1, pluginsFolder, null);
    if (err != 0)
        cancelInstall(err);
    err = addFile(MSSHARED + manifest2, null, PLUGIN_PFX + manifest2, pluginsFolder, null);
    if (err != 0)
        cancelInstall(err);
} else {
    logComment("All required MFC files already exist in " + pluginsFolder);
}

// local browser installed - reload
resetError();
err = performInstall();
if (err == 0)	
	refreshPlugins(true);  
else
	cancelInstall(err);

function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " K");
    logComment("  available: " + spaceAvailable + " K");
    return(false);
  }

  return(true);
}
